@@ -373,52 +373,23 @@ public:
   dict mainnamespace;
 };
 
-// allocates a new string using new [], and copies contents into it..
-static char* newstring( const char* contents )
-{
-  char* ret = new char[strlen( contents ) + 1];
-  strcpy( ret, contents );
-  return ret;
-}
-
 PythonScripter::PythonScripter()
 {
   d = new Private;
 
   // tell the python interpreter about our API..
 
-  // the newstring stuff is to prevent warnings about conversion from
-  // const char* to char*..
-  char* s = newstring( "kig" );
-#if PY_VERSION_HEX >= 0x03000000
-  PyImport_AppendInittab( s, PyInit_kig );
-#else
-  PyImport_AppendInittab( s, initkig );
-#endif
-  //  we can't delete this yet, since python keeps a pointer to it..
-  // This means we have a small but harmless memory leak here, but it
-  // doesn't hurt at all, since it could only be freed at the end of
-  // the program, at which time it is freed by the system anyway if we
-  // don't do it..
-  //delete [] s;
+  PyImport_AppendInittab( "kig", PyInit_kig );
 
   Py_Initialize();
 
-  s = newstring( "import math; from math import *;" );
-  PyRun_SimpleString( s );
-  delete [] s;
-  s = newstring( "import kig; from kig import *;" );
-  PyRun_SimpleString( s );
-  delete [] s;
-  s = newstring( "import traceback;" );
-  PyRun_SimpleString( s );
-  delete [] s;
+  PyRun_SimpleString( "import math; from math import *;" );
+  PyRun_SimpleString( "import kig; from kig import *;" );
+  PyRun_SimpleString( "import traceback;" );
 
   // find the main namespace..
 
-  s = newstring( "__main__" );
-  handle<> main_module( borrowed( PyImport_AddModule( s ) ) );
-  delete [] s;
+  handle<> main_module( borrowed( PyImport_AddModule( "__main__" ) ) );
 
   handle<> mnh(borrowed( PyModule_GetDict(main_module.get()) ));
   d->mainnamespace = extract<dict>( mnh.get() );
@@ -569,6 +540,7 @@ void PythonScripter::saveErrors()
   PyObject* poexcvalue;
   PyObject* poexctraceback;
   PyErr_Fetch( &poexctype, &poexcvalue, &poexctraceback );
+  PyErr_NormalizeException( &poexctype, &poexcvalue, &poexctraceback );
   handle<> exctypeh( poexctype );
   handle<> excvalueh( poexcvalue );
 
